<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>OutputWaveOutFactory</name>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="30"/>
        <source>WaveOut Plugin</source>
        <translation>WaveOut įskiepis</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="54"/>
        <source>About WaveOut Output Plugin</source>
        <translation>Apie WaveOut įskiepį</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="55"/>
        <source>Qmmp WaveOut Output Plugin</source>
        <translation>Qmmp WaveOut įskiepis</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="56"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../outputwaveoutfactory.cpp" line="57"/>
        <source>Based on aacDECdrop player</source>
        <translation>Sukurtas aacDECdrop grotuvo pagrindu</translation>
    </message>
</context>
</TS>
